@@ -69,7 +69,7 @@ odt_document <- function(fig_width = 5,
 
   # reference odt
   if (!is.null(reference_odt) && !identical(reference_odt, "default")) {
-    args <- c(args, "--reference-odt", pandoc_path_arg(reference_odt))
+    args <- c(args, reference_doc_arg("odt"), pandoc_path_arg(reference_odt))
   }
 
   # pandoc args
