@@ -171,7 +171,7 @@ pandoc_version <- function() {
 #' @inheritParams includes
 #'
 #' @param name Name of template variable to set.
-#' @param value Value of template variable.
+#' @param value Value of template variable (defaults to \code{true} if missing).
 #' @param toc \code{TRUE} to include a table of contents in the output.
 #' @param toc_depth Depth of headers to include in table of contents.
 #' @param highlight The name of a pandoc syntax highlighting theme.
@@ -207,7 +207,7 @@ NULL
 #' @rdname pandoc_args
 #' @export
 pandoc_variable_arg <- function(name, value) {
-  c("--variable", paste(name, "=", value, sep = ""))
+  c("--variable", if (missing(value)) name else paste(name, "=", value, sep = ""))
 }
 
 
@@ -250,20 +250,19 @@ pandoc_highlight_args <- function(highlight, default = "tango") {
 #' @rdname pandoc_args
 #' @export
 pandoc_latex_engine_args <- function(latex_engine) {
-  c("--latex-engine", find_latex_engine(latex_engine))
+  c(if (pandoc_available('2.0')) "--pdf-engine" else "--latex-engine",
+    find_latex_engine(latex_engine))
 }
 
+# For macOS, use a full path to the latex engine since the stripping
+# of the PATH environment variable by OSX 10.10 Yosemite prevents
+# pandoc from finding the engine in e.g. /usr/texbin
 find_latex_engine <- function(latex_engine) {
-  # use a full path to the latex engine on OSX since the stripping
-  # of the PATH environment variable by OSX 10.10 Yosemite prevents
-  # pandoc from finding the engine in e.g. /usr/texbin
-  if (is_osx()) {
-    # resolve path if it's not already an absolute path
-    if (!grepl("/", latex_engine, fixed = TRUE))
-      program_path <- find_program(latex_engine)
-    if (nzchar(program_path))
-      latex_engine <- program_path
-  }
+  # do not need full path if latex_engine is available from PATH
+  if (!is_osx() || nzchar(Sys.which(latex_engine))) return(latex_engine)
+  # resolve path if it's not already an absolute path
+  if (!grepl("/", latex_engine) && nzchar(path <- find_program(latex_engine)))
+    latex_engine <- path
   latex_engine
 }
 
@@ -368,6 +367,7 @@ pandoc_self_contained_html <- function(input, output) {
 
   # create a simple body-only template
   template <- tempfile(fileext = ".html")
+  on.exit(unlink(template), add = TRUE)
   writeLines("$body$", template)
 
   # convert from markdown to html to get base64 encoding
