@@ -6,7 +6,7 @@ knit_params_get <- function(input_lines, params) {
   if (packageVersion('yaml') < '2.1.14') knit_params <- mark_utf8(knit_params)
   default_params <- list()
   for (param in knit_params) {
-    default_params[[param$name]] <- param$value
+    default_params[param$name] <- list(param$value)
   }
 
   # validate params passed to render
@@ -30,7 +30,7 @@ knit_params_get <- function(input_lines, params) {
     invalid_params <- setdiff(names(params), names(default_params))
     if (length(invalid_params) > 0) {
       stop("render params not declared in YAML: ",
-           paste(invalid_params, sep = ", "))
+           paste(invalid_params, collapse = ", "))
     }
   }
 
@@ -101,7 +101,7 @@ params_value_to_ui <- function(inputControlFn, value, showDefault) {
 
 params_value_from_ui <- function(inputControlFn, value, uivalue) {
   if (identical(inputControlFn, shiny::fileInput)) {
-    uivalue$datapath
+    backup_file_input(uivalue$datapath)
   } else if (identical(inputControlFn, shiny::textInput)) {
     classes <- class(value)
     if ("POSIXct" %in% classes) {
@@ -121,6 +121,18 @@ params_value_from_ui <- function(inputControlFn, value, uivalue) {
   }
 }
 
+# Uploaded files will be deleted when the shiny UI is closed, so we need to back
+# them up to new temp files: https://github.com/rstudio/rmarkdown/issues/919
+backup_file_input <- function(files) {
+  files2 <- files
+  for (i in seq_along(files)) {
+    dir.create(d <- tempfile())
+    files2[i] <- file.path(d, basename(files[i]))
+  }
+  file.copy(files, files2)
+  files2
+}
+
 params_get_input <- function(param) {
   # Maps between value types and input: XXX
   default_inputs <- list(
