@@ -173,6 +173,10 @@ default_site <- function(input, encoding = getOption("encoding"), ...) {
                      quiet,
                      encoding, ...) {
 
+    site_yml  <- file.path(input, '_site.yml')
+    site_yml2 <- patch_html_document_options(config, encoding, site_yml)
+    on.exit(file.copy(site_yml2, site_yml, overwrite = TRUE), add = TRUE)
+
     # track outputs
     outputs <- c()
 
@@ -192,8 +196,6 @@ default_site <- function(input, encoding = getOption("encoding"), ...) {
       output <- suppressMessages(
         rmarkdown::render(x,
                           output_format = output_format,
-                          output_options = list(lib_dir = "site_libs",
-                                                self_contained = FALSE),
                           envir = envir,
                           quiet = quiet,
                           encoding = encoding)
@@ -418,4 +420,18 @@ site_config_file <- function(input) {
   file.path(input, "_site.yml")
 }
 
-
+# make sure the html_document format has options `lib_dir` and `self_contained`
+patch_html_document_options <- function(config, encoding, site_yml) {
+  opts <- config$output[['html_document']]
+  if (identical(opts, 'default')) opts <- list()
+  opts <- merge_lists(as.list(opts), list(
+    lib_dir = "site_libs", self_contained = FALSE
+  ))
+  config$output[['html_document']] <- opts
+  tmp <- tempfile()
+  file.copy(site_yml, tmp, overwrite = TRUE)
+  con <- file(site_yml, open = 'w', encoding = encoding)
+  on.exit(close(con), add = TRUE)
+  writeLines(yaml::as.yaml(config), con)
+  tmp
+}
