@@ -138,6 +138,8 @@ run <- function(file = "index.Rmd", dir = dirname(file), default_file = NULL,
     else
       render_args$encoding
 
+  if (is.null(render_args$envir)) render_args$envir <- parent.frame()
+
   # determine the runtime of the target file
   target_file <- ifelse(!is.null(file), file, default_file)
   if (!is.null(target_file))
@@ -273,8 +275,7 @@ rmarkdown_shiny_server <- function(dir, file, encoding, auto_reload, render_args
                                output_dir = dirname(output_dest),
                                output_options = output_opts,
                                intermediates_dir = dirname(output_dest),
-                               runtime = "shiny",
-                               envir = new.env()),
+                               runtime = "shiny"),
                           render_args)
       result_path <- shiny::maskReactiveContext(do.call(render, args))
 
@@ -304,9 +305,28 @@ rmarkdown_shiny_server <- function(dir, file, encoding, auto_reload, render_args
       }
       shinyHTML_with_deps(result_path, dependencies)
     })
-    output$`__reactivedoc__` <- shiny::renderUI({
+
+    doc_ui <- shiny::renderUI({
       doc()
     })
+
+    # For test snapshots. (The snapshotPreprocessOutput function was added
+    # in shiny 1.0.4.)
+    if (exists("snapshotPreprocessOutput", asNamespace("shiny"))) {
+      doc_ui <- shiny::snapshotPreprocessOutput(
+        doc_ui,
+        function(value) {
+          # Since the html data can be very large, just record a hash of it.
+          value$html <- sprintf("[html data sha1: %s]",
+            digest::digest(value$html, algo = "sha1", serialize = FALSE)
+          )
+
+          value
+        }
+      )
+    }
+
+    output$`__reactivedoc__` <- doc_ui
   }
 }
 
